@@ -10,11 +10,25 @@ sub new {
 
 {
     no warnings 'redefine';
-    *Elastijk::new = *Elastijk::oo::new;
+    *Elastijk::new = sub { shift; Elastijk::oo->new(@_) };
 };
 
+sub request {
+    my ($self, %args) = @_;
+    $args{$_} ||= $self->{$_} for grep { exists $self->{$_} } qw(host port index type);
+    return Elastijk::request(\%args);
+}
+
+sub request_raw {
+    my ($self, %args) = @_;
+    $args{$_} ||= $self->{$_} for grep { exists $self->{$_} } qw(host port index type);
+    return Elastijk::request_raw(\%args);
+}
+
 sub index {
-    my ($self, $type, $doc) = @_;
+    my $self = shift;
+    my $doc  = pop;
+    my $type = @_ ? $_[0] : $self->{type};
 
     if (ref($doc) eq 'ARRAY') {
         my $body = "";
@@ -29,27 +43,20 @@ sub index {
             }
         }
 
-        my ($status, $res) = Elastijk::request_raw({
-            host => $self->{host},
-            port => $self->{port},
+        my ($status, $res) = $self->request_raw(
             method => "POST",
-            index => $self->{index},
-            type => $type,
+            defined($type) ? ( type => $type ) : (),
             command => "_bulk",
             body => $body,
-        });
+        );
         $res = $Elastijk::JSON->decode($res);
         return $res;
-    }
-    elsif (ref($doc) eq 'HASH') {
-        my ($status, $res) = Elastijk::request({
-            host => $self->{host},
-            port => $self->{port},
+    } elsif (ref($doc) eq 'HASH') {
+        my ($status, $res) = $self->request(
             method => "POST",
-            index => $self->{index},
-            type  => $type,
+            defined($type) ? ( type => $type ) : (),
             body => $doc,
-        });
+        );
         return $res;
     }
 
@@ -58,15 +65,11 @@ sub index {
 
 sub get {
     my ($self, %spec) = @_;
-    my $id = $spec{id};
-    my ($status, $res) = Elastijk::request({
-        host => $self->{host},
-        port => $self->{port},
-        method => "GET",
-        index => $spec{index} || $self->{index},
-        type => $spec{type} || $self->{type},
-        command => $id
-    });
+    my ($status, $res) = $self->request(
+        exists($spec{index}) ? ( index => $spec{index} ) : (),
+        exists($spec{type})  ? ( type  => $spec{type}  ) : (),
+        command => $spec{id},
+    );
     return $res;
 }
 
@@ -74,15 +77,11 @@ sub exists {
     my ($self, %spec) = @_;
 
     if ( !ref($spec{index}) ) {
-        my ($status, undef) = Elastijk::request({
-            host => $self->{host},
-            port => $self->{port},
+        my ($status, undef) = $self->request(
             method => "HEAD",
-            index => $spec{index},
-            !$spec{type} ?() : (
-                type => $spec{type}
-            ),
-        });
+            exists($spec{index}) ? ( index => $spec{index} ) : (),
+            exists($spec{type})  ? ( type  => $spec{type}  ) : (),
+        );
 
         return $status eq '200';
     }
@@ -94,13 +93,11 @@ sub create {
     my ($self, %spec) = @_;
     my $res = {};
     for my $index_name ( keys %{ $spec{index} } ) {
-        my ($status, $body) = Elastijk::request({
-            host => $self->{host},
-            port => $self->{port},
+        my ($status, $body) = $self->request(
             index => $index_name,
             method => "PUT",
             body => $spec{index}{$index_name}
-        });
+        );
         $res->{$index_name} = { status => $status, body => $body }
     }
 
@@ -111,12 +108,10 @@ sub delete {
     my ($self, %spec) = @_;
     my $res = {};
     my $index_name = $spec{index};
-    my ($status, $body) = Elastijk::request({
-        host => $self->{host},
-        port => $self->{port},
+    my ($status, $body) = $self->request(
         index => $index_name,
         method => "DELETE"
-    });
+    );
     $res->{$index_name} = { status => $status, body => $body };
     return $res;
 }
@@ -125,20 +120,13 @@ sub search {
     my $self = shift;
     my %args = @_;
     my $search_type = delete $args{search_type};
-    my ($status, $body) = Elastijk::request({
-        method => "GET",
-        host => $self->{host},
-        port => $self->{port},
-        $self->{index} ? ( index => $self->{index} ) : (),
-        $self->{type}  ? ( type  => $self->{type}  ) : (),
-
+    my ($status, $body) = $self->request(
         command => "_search",
         $search_type ? (
             uri_param => { search_type => $search_type }
         ) : (),
-
         body => \%args,
-    });
+    );
 
     return {
         status => $status,
@@ -149,17 +137,10 @@ sub search {
 
 sub uri_search {
     my ($self, %args) = @_;
-    my ($status, $body) = Elastijk::request({
-        method => "GET",
-        host => $self->{host},
-        port => $self->{port},
-        $self->{index} ? ( index => $self->{index} ) : (),
-        $self->{type}  ? ( type  => $self->{type}  ) : (),
-
+    my ($status, $body) = $self->request(
         command => "_search",
         uri_param => \%args,
-    });
-
+    );
     return {
         status => $status,
         body => $body,
